Re: [StGit PATCH 2/2] Reuse the same temp index in a transaction
- From
Karl Hasselström <kha@treskal.com>
- Date
- Jul 14, 2008, 06:35 UTC
- Message-ID
- <20080714063551.GD20751@diana.vm.bytemark.co.uk>
- In-Reply-To
- <b0943d9e0807120324l7674c010w9a8e4a0bbdeeee65@mail.gmail.com>
On 2008-07-12 11:24:24 +0100, Catalin Marinas wrote:
Show 18 quoted lines
> 2008/7/2 Karl Hasselström <kha@treskal.com>: > > > Instead of making a new temp index every time we need one, just > > keep reusing the same one. And keep track of which tree is > > currently stored in it -- if we do several consecutive successful > > pushes, it's always going to be the "right" tree so that we don't > > have to call read-tree before each patch application. > > > > The motivation behind this change is of course that it makes > > things faster. > > > > (The same simple test as in the previous patch -- pushing 250 > > patches in a 32k-file repository, with one file-level merge > > necessary per push -- went from 0.36 to 0.19 seconds per patch > > with this patch applied.) > > That's an impressive improvement (together with the previous patch). > Is this with the new patch log infrastructure?
Yes, with all the bells and whistles -- in particular, with the overhead of the simplified log. (But note that it's a synthetic benchmark, and not a real linux-kernel patch series.)
--
Karl Hasselström, kha@treskal.com
www.treskal.com/kalle